@@ -2,13 +2,13 @@
 /**
 *
 * @package install
-* @version $Id: database_update.php 8678 2008-07-06 16:35:41Z acydburn $
+* @version $Id: database_update.php 9187 2008-12-12 14:47:03Z acydburn $
 * @copyright (c) 2006 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
-$updates_to_version = '3.0.2';
+$updates_to_version = '3.0.4';
 
 // Return if we "just include it" to find out for which version the database update is responsible for
 if (defined('IN_PHPBB') && defined('IN_INSTALL'))
@@ -78,7 +78,7 @@ if (version_compare(PHP_VERSION, '6.0.0-dev', '>='))
 }
 else
 {
-	set_magic_quotes_runtime(0);
+	@set_magic_quotes_runtime(0);
 	define('STRIP', (get_magic_quotes_gpc()) ? true : false);
 }
 
@@ -531,6 +531,65 @@ $database_update_info = array(
 	),
 	// No changes from 3.0.2-RC2 to 3.0.2
 	'3.0.2-RC2'		=> array(),
+
+	// Changes from 3.0.2 to 3.0.3-RC1
+	'3.0.2'			=> array(
+		// Add the following columns
+		'add_columns'		=> array(
+			STYLES_TEMPLATE_TABLE			=> array(
+				'template_inherits_id'		=> array('UINT:4', 0),
+				'template_inherit_path'		=> array('VCHAR', ''),
+			),
+			GROUPS_TABLE					=> array(
+				'group_max_recipients'		=> array('UINT', 0),
+			),
+		),
+	),
+
+	// No changes from 3.0.3-RC1 to 3.0.3
+	'3.0.3-RC1'		=> array(),
+
+	// Changes from 3.0.3 to 3.0.4-RC1
+	'3.0.3'			=> array(
+		'add_columns'		=> array(
+			PROFILE_FIELDS_TABLE			=> array(
+				'field_show_profile'		=> array('BOOL', 0),
+			),
+		),
+		'change_columns'	=> array(
+			STYLES_TABLE				=> array(
+				'style_id'				=> array('UINT', NULL, 'auto_increment'),
+				'template_id'			=> array('UINT', 0),
+				'theme_id'				=> array('UINT', 0),
+				'imageset_id'			=> array('UINT', 0),
+			),
+			STYLES_IMAGESET_TABLE		=> array(
+				'imageset_id'				=> array('UINT', NULL, 'auto_increment'),
+			),
+			STYLES_IMAGESET_DATA_TABLE	=> array(
+				'image_id'				=> array('UINT', NULL, 'auto_increment'),
+				'imageset_id'			=> array('UINT', 0),
+			),
+			STYLES_THEME_TABLE			=> array(
+				'theme_id'				=> array('UINT', NULL, 'auto_increment'),
+			),
+			STYLES_TEMPLATE_TABLE		=> array(
+				'template_id'			=> array('UINT', NULL, 'auto_increment'),
+			),
+			STYLES_TEMPLATE_DATA_TABLE	=> array(
+				'template_id'			=> array('UINT', 0),
+			),
+			FORUMS_TABLE				=> array(
+				'forum_style'			=> array('USINT', 0),
+			),
+			USERS_TABLE					=> array(
+				'user_style'			=> array('UINT', 0),
+			),
+		),
+	),
+
+	// Changes from 3.0.4-RC1 to 3.0.4
+	'3.0.4-RC1'		=> array(),
 );
 
 // Determine mapping database type
@@ -541,7 +600,7 @@ switch ($db->sql_layer)
 	break;
 
 	case 'mysql4':
-		if (version_compare($db->mysql_version, '4.1.3', '>='))
+		if (version_compare($db->sql_server_info(true), '4.1.3', '>='))
 		{
 			$map_dbms = 'mysql_41';
 		}
@@ -1402,7 +1461,7 @@ if (function_exists('exit_handler'))
 */
 function change_database_data(&$no_updates, $version)
 {
-	global $db, $map_dbms, $errored, $error_ary, $config, $phpbb_root_path;
+	global $db, $map_dbms, $errored, $error_ary, $config, $phpbb_root_path, $phpEx;
 
 	switch ($version)
 	{
@@ -1820,6 +1879,162 @@ function change_database_data(&$no_updates, $version)
 		// No changes from 3.0.2-RC2 to 3.0.2
 		case '3.0.2-RC2':
 		break;
+
+		// Changes from 3.0.2 to 3.0.3-RC1
+		case '3.0.2':
+			set_config('enable_queue_trigger', '0');
+			set_config('queue_trigger_posts', '3');
+
+			set_config('pm_max_recipients', '0');
+
+			// Set maximum number of recipients for the registered users, bots, guests group
+			$sql = 'UPDATE ' . GROUPS_TABLE . ' SET group_max_recipients = 5
+				WHERE ' . $db->sql_in_set('group_name', array('GUESTS', 'REGISTERED', 'REGISTERED_COPPA', 'BOTS'));
+			_sql($sql, $errored, $error_ary);
+
+			// Not prefilling yet
+			set_config('dbms_version', '');
+
+			// Add new permission u_masspm_group and duplicate settings from u_masspm
+			include_once($phpbb_root_path . 'includes/acp/auth.' . $phpEx);
+			$auth_admin = new auth_admin();
+
+			// Only add the new permission if it does not already exist
+			if (empty($auth_admin->acl_options['id']['u_masspm_group']))
+			{
+				$auth_admin->acl_add_option(array('global' => array('u_masspm_group')));
+
+				// Now the tricky part, filling the permission
+				$old_id = $auth_admin->acl_options['id']['u_masspm'];
+				$new_id = $auth_admin->acl_options['id']['u_masspm_group'];
+
+				$tables = array(ACL_GROUPS_TABLE, ACL_ROLES_DATA_TABLE, ACL_USERS_TABLE);
+
+				foreach ($tables as $table)
+				{
+					$sql = 'SELECT *
+						FROM ' . $table . '
+						WHERE auth_option_id = ' . $old_id;
+					$result = _sql($sql, $errored, $error_ary);
+
+					$sql_ary = array();
+					while ($row = $db->sql_fetchrow($result))
+					{
+						$row['auth_option_id'] = $new_id;
+						$sql_ary[] = $row;
+					}
+					$db->sql_freeresult($result);
+
+					if (sizeof($sql_ary))
+					{
+						$db->sql_multi_insert($table, $sql_ary);
+					}
+				}
+
+				// Remove any old permission entries
+				$auth_admin->acl_clear_prefetch();
+			}
+
+			/**
+			* Do not resync post counts here. An admin may do this later from the ACP
+			$start = 0;
+			$step = ($config['num_posts']) ? (max((int) ($config['num_posts'] / 5), 20000)) : 20000;
+
+			$sql = 'UPDATE ' . USERS_TABLE . ' SET user_posts = 0';
+			_sql($sql, $errored, $error_ary);
+
+			do
+			{
+				$sql = 'SELECT COUNT(post_id) AS num_posts, poster_id
+					FROM ' . POSTS_TABLE . '
+					WHERE post_id BETWEEN ' . ($start + 1) . ' AND ' . ($start + $step) . '
+						AND post_postcount = 1 AND post_approved = 1
+					GROUP BY poster_id';
+				$result = _sql($sql, $errored, $error_ary);
+
+				if ($row = $db->sql_fetchrow($result))
+				{
+					do
+					{
+						$sql = 'UPDATE ' . USERS_TABLE . " SET user_posts = user_posts + {$row['num_posts']} WHERE user_id = {$row['poster_id']}";
+						_sql($sql, $errored, $error_ary);
+					}
+					while ($row = $db->sql_fetchrow($result));
+
+					$start += $step;
+				}
+				else
+				{
+					$start = 0;
+				}
+				$db->sql_freeresult($result);
+			}
+			while ($start);
+			*/
+
+			$sql = 'UPDATE ' . MODULES_TABLE . '
+				SET module_auth = \'acl_a_email && cfg_email_enable\'
+				WHERE module_class = \'acp\'
+					AND module_basename = \'email\'';
+			_sql($sql, $errored, $error_ary);
+
+			$no_updates = false;
+		break;
+
+		// Changes from 3.0.3-RC1 to 3.0.3
+		case '3.0.3-RC1':
+			$sql = 'UPDATE ' . LOG_TABLE . "
+				SET log_operation = 'LOG_DELETE_TOPIC'
+				WHERE log_operation = 'LOG_TOPIC_DELETED'";
+			_sql($sql, $errored, $error_ary);
+
+			$no_updates = false;
+		break;
+
+		// Changes from 3.0.3 to 3.0.4-RC1
+		case '3.0.3':
+			// Update the Custom Profile Fields based on previous settings to the new format
+			$sql = 'SELECT field_id, field_required, field_show_on_reg, field_hide
+					FROM ' . PROFILE_FIELDS_TABLE;
+			$result = _sql($sql, $errored, $error_ary);
+
+			while ($row = $db->sql_fetchrow($result))
+			{
+				$sql_ary = array(
+					'field_required'	=> 0,
+					'field_show_on_reg'	=> 0,
+					'field_hide'		=> 0,
+					'field_show_profile'=> 0,
+				);
+
+				if ($row['field_required'])
+				{
+					$sql_ary['field_required'] = $sql_ary['field_show_on_reg'] = $sql_ary['field_show_profile'] = 1;
+				}
+				else if ($row['field_show_on_reg'])
+				{
+					$sql_ary['field_show_on_reg'] = $sql_ary['field_show_profile'] = 1;
+				}
+				else if ($row['field_hide'])
+				{
+					// Only administrators and moderators can see this CPF, if the view is enabled, they can see it, otherwise just admins in the acp_users module
+					$sql_ary['field_hide'] = 1;
+				}
+				else
+				{
+					// equivelant to "none", which is the "Display in user control panel" option
+					$sql_ary['field_show_profile'] = 1;
+				}
+
+				_sql('UPDATE ' . PROFILE_FIELDS_TABLE . ' SET ' . $db->sql_build_array('UPDATE', $sql_ary) . ' WHERE field_id = ' . $row['field_id'], $errored, $error_ary);
+			}
+
+			$no_updates = false;
+		break;
+
+		// Changes from 3.0.4-RC1 to 3.0.4
+		case '3.0.4-RC1':
+		break;
 	}
 }
 
@@ -2954,4 +3169,4 @@ function utf8_new_clean_string($text)
 	return trim($text);
 }
 
-?>
\ No newline at end of file
+?>
