@@ -1,5 +1,5 @@
 #
-# $Id: sqlite_schema.sql 8666 2008-06-21 16:04:13Z acydburn $
+# $Id: sqlite_schema.sql 9129 2008-11-27 13:44:24Z acydburn $
 #
 
 BEGIN TRANSACTION;
@@ -304,6 +304,7 @@ CREATE TABLE phpbb_groups (
 	group_sig_chars INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	group_receive_pm INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	group_message_limit INTEGER UNSIGNED NOT NULL DEFAULT '0',
+	group_max_recipients INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	group_legend INTEGER UNSIGNED NOT NULL DEFAULT '1'
 );
 
@@ -532,6 +533,7 @@ CREATE TABLE phpbb_profile_fields (
 	field_validation varchar(20) NOT NULL DEFAULT '',
 	field_required INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	field_show_on_reg INTEGER UNSIGNED NOT NULL DEFAULT '0',
+	field_show_profile INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	field_hide INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	field_no_view INTEGER UNSIGNED NOT NULL DEFAULT '0',
 	field_active INTEGER UNSIGNED NOT NULL DEFAULT '0',
@@ -713,7 +715,9 @@ CREATE TABLE phpbb_styles_template (
 	template_copyright varchar(255) NOT NULL DEFAULT '',
 	template_path varchar(100) NOT NULL DEFAULT '',
 	bbcode_bitfield varchar(255) NOT NULL DEFAULT 'kNg=',
-	template_storedb INTEGER UNSIGNED NOT NULL DEFAULT '0'
+	template_storedb INTEGER UNSIGNED NOT NULL DEFAULT '0',
+	template_inherits_id INTEGER UNSIGNED NOT NULL DEFAULT '0',
+	template_inherit_path varchar(255) NOT NULL DEFAULT ''
 );
 
 CREATE UNIQUE INDEX phpbb_styles_template_tmplte_nm ON phpbb_styles_template (template_name);
