@@ -4,7 +4,7 @@
 * common [English]
 *
 * @package language
-* @version $Id: common.php 8555 2008-05-15 14:10:11Z Kellanved $
+* @version $Id: common.php 9162 2008-12-03 11:18:31Z acydburn $
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -170,6 +170,8 @@ $lang = array_merge($lang, array(
 	'ERR_JAB_AUTH'						=> 'Could not authorise on Jabber server.',
 	'ERR_JAB_CONNECT'					=> 'Could not connect to Jabber server.',
 	'ERR_UNABLE_TO_LOGIN'				=> 'The specified username or password is incorrect.',
+	'ERR_UNWATCHING'					=> 'An error occured while trying to unsubscribe.',
+	'ERR_WATCHING'						=> 'An error occured while trying to subscribe.',
 	'ERR_WRONG_PATH_TO_PHPBB'			=> 'The phpBB path specified appears to be invalid.',
 	'EXPAND_VIEW'						=> 'Expand view',
 	'EXTENSION'							=> 'Extension',
@@ -262,7 +264,7 @@ $lang = array_merge($lang, array(
 	'HOME'							=> 'Home',
 
 	'ICQ'						=> 'ICQ',
-	'ICQ_STATUS'				=> 'ICQ status',	
+	'ICQ_STATUS'				=> 'ICQ status',
 	'IF'						=> 'If',
 	'IMAGE'						=> 'Image',
 	'IMAGE_FILETYPE_INVALID'	=> 'Image file type %d for mimetype %s not supported.',
@@ -278,7 +280,7 @@ $lang = array_merge($lang, array(
 
 	'JABBER'				=> 'Jabber',
 	'JOINED'				=> 'Joined',
-	'JUMP_PAGE'				=> 'Enter the page number you wish to go to.',
+	'JUMP_PAGE'				=> 'Enter the page number you wish to go to',
 	'JUMP_TO'				=> 'Jump to',
 	'JUMP_TO_PAGE'			=> 'Click to jump to page…',
 
@@ -333,7 +335,7 @@ $lang = array_merge($lang, array(
 	'MODERATORS'			=> 'Moderators',
 	'MONTH'					=> 'Month',
 	'MOVE'					=> 'Move',
-	'MSNM'					=> 'MSNM/WLM',	
+	'MSNM'					=> 'MSNM/WLM',
 
 	'NA'						=> 'N/A',
 	'NEWEST_USER'				=> 'Our newest member <strong>%s</strong>',
@@ -355,7 +357,7 @@ $lang = array_merge($lang, array(
 	'NOTIFY_ADMIN_EMAIL'		=> 'Please notify the board administrator or webmaster: <a href="mailto:%1$s">%1$s</a>',
 	'NO_ACCESS_ATTACHMENT'		=> 'You are not allowed to access this file.',
 	'NO_ACTION'					=> 'No action specified.',
-	'NO_ADMINISTRATORS'			=> 'No administrators assigned at this board.',
+	'NO_ADMINISTRATORS'			=> 'There are no administrators.',
 	'NO_AUTH_ADMIN'				=> 'Access to the Administration Control Panel is not allowed as you do not have administrative permissions.',
 	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'You are not able to re-authenticate as a different user.',
 	'NO_AUTH_OPERATION'			=> 'You do not have the necessary permissions to complete this operation.',
@@ -372,7 +374,7 @@ $lang = array_merge($lang, array(
 	'NO_MEMBERS'				=> 'No members found for this search criterion.',
 	'NO_MESSAGES'				=> 'No messages',
 	'NO_MODE'					=> 'No mode specified.',
-	'NO_MODERATORS'				=> 'No moderators assigned at this board.',
+	'NO_MODERATORS'				=> 'There are no moderators.',
 	'NO_NEW_MESSAGES'			=> 'No new messages',
 	'NO_NEW_PM'					=> '<strong>0</strong> new messages',
 	'NO_NEW_POSTS'				=> 'No new posts',
@@ -392,6 +394,13 @@ $lang = array_merge($lang, array(
 	'NO_USERS'					=> 'The requested users do not exist.',
 	'NO_USER_SPECIFIED'			=> 'No username was specified.',
 
+	// Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
+	'NUM_POSTS_IN_QUEUE'		=> array(
+		0			=> 'No posts in queue',		// 0
+		1			=> '1 post in queue',		// 1
+		2			=> '%d posts in queue',		// 2+
+	),
+
 	'OCCUPATION'				=> 'Occupation',
 	'OFFLINE'					=> 'Offline',
 	'ONLINE'					=> 'Online',
@@ -500,7 +509,7 @@ $lang = array_merge($lang, array(
 	'SEARCHING_FORUMS'			=> 'Searching forums',
 	'SEARCH_ACTIVE_TOPICS'		=> 'View active topics',
 	'SEARCH_FOR'				=> 'Search for',
-	'SEARCH_FORUM'				=> 'Search this forum…',	
+	'SEARCH_FORUM'				=> 'Search this forum…',
 	'SEARCH_NEW'				=> 'View new posts',
 	'SEARCH_POSTS_BY'			=> 'Search posts by',
 	'SEARCH_SELF'				=> 'View your posts',
@@ -543,6 +552,8 @@ $lang = array_merge($lang, array(
 	'THE_TEAM'			=> 'The team',
 	'TIME'				=> 'Time',
 
+	'TOO_LONG'						=> 'The value you entered is too long.',
+
 	'TOO_LONG_AIM'					=> 'The screenname you entered is too long.',
 	'TOO_LONG_CONFIRM_CODE'			=> 'The confirm code you entered is too long.',
 	'TOO_LONG_DATEFORMAT'			=> 'The date format you entered is too long.',
@@ -563,6 +574,8 @@ $lang = array_merge($lang, array(
 
 	'TOO_MANY_VOTE_OPTIONS'			=> 'You have tried to vote for too many options.',
 
+	'TOO_SHORT'						=> 'The value you entered is too short.',
+
 	'TOO_SHORT_AIM'					=> 'The screenname you entered is too short.',
 	'TOO_SHORT_CONFIRM_CODE'		=> 'The confirm code you entered is too short.',
 	'TOO_SHORT_DATEFORMAT'			=> 'The date format you entered is too short.',
@@ -674,7 +687,7 @@ $lang = array_merge($lang, array(
 	'YEAR'				=> 'Year',
 	'YEAR_MONTH_DAY'	=> '(YYYY-MM-DD)',
 	'YES'				=> 'Yes',
-	'YIM'				=> 'YIM',	
+	'YIM'				=> 'YIM',
 	'YOU_LAST_VISIT'	=> 'Last visit was: %s',
 	'YOU_NEW_PM'		=> 'A new private message is waiting for you in your Inbox.',
 	'YOU_NEW_PMS'		=> 'New private messages are waiting for you in your Inbox.',
@@ -684,6 +697,12 @@ $lang = array_merge($lang, array(
 		'TODAY'		=> 'Today',
 		'TOMORROW'	=> 'Tomorrow',
 		'YESTERDAY'	=> 'Yesterday',
+		'AGO'		=> array(
+			0		=> 'less than a minute ago',
+			1		=> '%d minute ago',
+			2		=> '%d minutes ago',
+			60		=> '1 hour ago',
+		),
 
 		'Sunday'	=> 'Sunday',
 		'Monday'	=> 'Monday',
@@ -738,6 +757,7 @@ $lang = array_merge($lang, array(
 		'-7'	=> 'UTC - 7 hours',
 		'-6'	=> 'UTC - 6 hours',
 		'-5'	=> 'UTC - 5 hours',
+		'-4.5'	=> 'UTC - 4:30 hours',
 		'-4'	=> 'UTC - 4 hours',
 		'-3.5'	=> 'UTC - 3:30 hours',
 		'-3'	=> 'UTC - 3 hours',
@@ -781,6 +801,7 @@ $lang = array_merge($lang, array(
 		'-7'	=> '[UTC - 7] Mountain Standard Time',
 		'-6'	=> '[UTC - 6] Central Standard Time',
 		'-5'	=> '[UTC - 5] Eastern Standard Time',
+		'-4.5'	=> '[UTC - 4:30] Venezuelan Standard Time',
 		'-4'	=> '[UTC - 4] Atlantic Standard Time',
 		'-3.5'	=> '[UTC - 3:30] Newfoundland Standard Time',
 		'-3'	=> '[UTC - 3] Amazon Standard Time, Central Greenland Time',
